@@ -23,6 +23,10 @@ def test_suite():
         robottestsuite = robotsuite.RobotTestSuite(robot_test)
         robottestsuite.level = ROBOT_TEST_LEVEL
         suite.addTests(
-            [layered(robottestsuite, layer=COLLECTIVE_EMBEDDEDPAGE_ACCEPTANCE_TESTING),]
+            [
+                layered(
+                    robottestsuite, layer=COLLECTIVE_EMBEDDEDPAGE_ACCEPTANCE_TESTING
+                ),
+            ]
         )
     return suite
